@@ -5,20 +5,18 @@
  *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef CACHEDNETWORKACCESSMANAGER_H
-#define CACHEDNETWORKACCESSMANAGER_H
+#pragma once
 
-#include <KIO/AccessManager>
 #include <QNetworkAccessManager>
 #include <QQmlNetworkAccessManagerFactory>
 
-class Q_DECL_EXPORT CachedNetworkAccessManager : public KIO::AccessManager
+#include "discovercommon_export.h"
+
+class DISCOVERCOMMON_EXPORT CachedNetworkAccessManager : public QNetworkAccessManager
 {
     Q_OBJECT
 public:
     explicit CachedNetworkAccessManager(const QString &path, QObject *parent = nullptr);
 
-    virtual QNetworkReply *createRequest(Operation op, const QNetworkRequest &request, QIODevice *outgoingData = nullptr) override;
+    QNetworkReply *createRequest(Operation op, const QNetworkRequest &request, QIODevice *outgoingData = nullptr) override;
 };
-
-#endif // CACHEDNETWORKACCESSMANAGER_H
