@@ -108,7 +108,7 @@ public:
     QString arch() const;
     QString branch() const;
     bool canExecute() const override;
-    QStringList categories() override;
+    bool hasCategory(const QString &category) const override;
     QString comment() override;
     quint64 downloadSize() const;
     QVariant icon() const override;
@@ -222,6 +222,8 @@ public:
 
     [[nodiscard]] bool hasResolvedIcon() const override;
     void resolveIcon() override;
+    QString verifiedMessage() const override;
+    bool updateNeedsAttention() override;
 
 Q_SIGNALS:
     void hasDataChanged();
@@ -231,6 +233,7 @@ Q_SIGNALS:
 private:
     void setEolReason(const QString &reason);
     void loadPermissions();
+    QVector<FlatpakPermission> readPermissions(const QString &file) const;
 
     const AppStream::Component m_appdata;
     FlatpakResource::Id m_id;
@@ -260,6 +263,7 @@ private:
     QVector<QByteArray> m_toUpdate;
     bool m_stockIcon;
     std::optional<QIcon> m_icon;
+    QString m_newPermissions;
 };
 
 inline uint qHash(const FlatpakResource::Id &key)
